@@ -4,14 +4,14 @@ webpage: https://www.quantmoon.tech//
 """
 
 from enigmx.classEnigmx import EnigmX
-from enigmx.utils import EquitiesEnigmxUniverse
+#from enigmx.utils import EquitiesEnigmxUniverse
 from sklearn.tree import DecisionTreeClassifier
 from sklearn.ensemble import GradientBoostingClassifier 
 
 
 instance = EnigmX(bartype = 'VOLUME', 
                   method = 'MDA', 
-                  base_path = 'D:/feature_importance/') 
+                  base_path = '/home/heligp4/.local/lib/python3.7/site-packages/enigmx/') 
 
 params_for_tuning = {
     'max_leaf_nodes': list(range(2, 20)), 
@@ -20,8 +20,8 @@ params_for_tuning = {
 
 instance.get_feature_importance(    
                    model = GradientBoostingClassifier(), 
-                   list_stocks = EquitiesEnigmxUniverse[10:20], 
-                   score_constraint = 0.3)
+                   list_stocks = ['ACIW', 'ACN', 'ADBE', 'ADM', 'AEO', 'AES', 'AFL', 'AGCO', 'AGI', 'AGIO'], 
+                   score_constraint = 0.3,server_name="34.67.233.155",database="BARS-FEATURES")
 
 instance.get_model_tunning(exo_process = True, endo_process = True, 
                            exo_model = DecisionTreeClassifier(),  
