@@ -1317,7 +1317,7 @@ def global_list_stocks(data_dir,
     return list_stocks
 
 # nominación de lista de acciones para ingesta directa de path 
-EquitiesEnigmxUniverse = global_list_stocks('D:/data_repository/')
+#EquitiesEnigmxUniverse = global_list_stocks('D:/data_repository/')
 
 #Data Tunning Preparation| CAMBIARLO POR SQL 
 def dataPreparation_forTuning(csv_path,
